from setuptools import setup

setup(name='BiNPr_distributions',
      version='1.3',
      description='Gaussian and Binomial probability distributions',
      packages=['BiNPr_distributions'],
      author = 'Ahmed Md',
      author_email = 'freda31k@gmail.com',
      zip_safe=False)
